<?php

namespace App\Http\Controllers\admin;

use PDF;
use App\Models\Submission;
use App\Models\Product;
use App\Models\Supplier;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;

class SubmissionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $submissions = Submission::query();

        if ($request->search) {
            $search = $request->search;
            $submissions->where('name', 'LIKE', "%{$search}%");
        }

        $submissions = $submissions->whereStatus('created')->latest()->paginate(50);

        return view('admin.submission.all', compact('submissions'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.submission.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $data = $request->validate([
            'name' => 'required',
            'note' => 'nullable',
            'room_id' => 'required',
            'release' => 'required',
            'suppliers' => 'required|array',
            'products' => 'required|array',
            'quantities' => 'required|array',
        ]);

        $user = auth()->user();
        $data['status'] = 'created';
        $submission = $user->submissions()->create($data);

        foreach ($data['products'] as $index => $productId) {
            $product = Product::find($productId);
            $price = $product->price;

            $supplierId = $data['suppliers'][$index];
            $quantity = $data['quantities'][$index];
            $total = $price * $quantity;

            $submission->products()->attach($productId, [
                'supplier_id' => $supplierId,
                'quantity' => $quantity,
                'price' => $price,
                'total' => $total,
            ]);
        }

        $submission->update(['sum' => $submission->products->sum('pivot.total')]);

        alert()->success('New submission created');
        return redirect()->route('submission.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Submission  $submission
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function show(Submission $submission, Request $request)
    {
        $suppliers = $submission->products->pluck('supplier_id')->unique();
        $pdf = $request->pdf;

        if ($request->pdf) {
            $html = view('admin.submission.show', compact('suppliers', 'submission', 'pdf'))->render();
            $pdf = PDF::loadHTML($html);
            $name = 'submission_' . $submission->id;
            return $pdf->download("$name.pdf");
        }

        return view('admin.submission.show', compact('submission', 'suppliers', 'pdf'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Submission  $submission
     * @return \Illuminate\Http\Response
     */
    public function edit(Submission $submission)
    {
        return view('admin.submission.edit', compact('submission'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Submission  $submission
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Submission $submission)
    {
        $data = $request->validate([
            'name' => 'required',
            'note' => 'nullable',
            'release' => 'required',
            'suppliers' => 'required|array',
            'products' => 'required|array',
            'quantities' => 'required|array',
        ]);

        $data['status'] = 'created';
        $submission->products()->sync([]);

        foreach ($data['products'] as $index => $productId) {
            $product = Product::find($productId);
            $price = $product->price;

            $supplierId = $data['suppliers'][$index];
            $quantity = $data['quantities'][$index];
            $total = $price * $quantity;

            $submission->products()->attach($productId, [
                'supplier_id' => $supplierId,
                'quantity' => $quantity,
                'price' => $price,
                'total' => $total,
            ]);
        }

        $submission->update(['sum' => $submission->products->sum('pivot.total')]);
        $submission->update($data);

        alert()->success('Submission updated');
        return redirect()->route('submission.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Submission  $submission
     * @return \Illuminate\Http\Response
     */
    public function destroy(Submission $submission)
    {
        $submission->products()->sync([]);
        $submission->delete();

        alert()->success('Submission deleted');
        return redirect()->route('submission.index');
    }
}
